/*
 * This example sketch shows how you can manage the nRF5 pin mapping as part of your code.
 * You can use the method for any nRF51822 or nRF52832 board or module.
 * 
 * Most components, like UART, SPI, Wire Bus, of the nRF5 series chips don't
 * have a fixed pin mapping. There are some pins with restrictions like analog
 * inputs, NFC or pins near the radio module. Please refer the latest
 * documentation about pin restrictions at http://infocenter.nordicsemi.com 
 * 
 * To use the custom pin mapping you have to do following steps:
 * 
 * 1. Install "arduino-nrf5" like described at
 *    https://github.com/sandeepmistry/arduino-nRF5/
 * 2. Install the "My Sensors nRF5 Boards" with the board manager like
 *    explained at https://github.com/mysensors/ArduinoBoards
 * 3. Copy the files "MyNRF5Board.cpp" and "MyNRF5Board.h" from
 *    "MyNRF5Board" example into your sketch.
 * 4. Modify pin mappings in "MyNRF5Board.cpp" and "MyNRF5Board.h" to fit
 *    your requirements.
 * 5. Select "MyNRF5Board nrf52832" or "MyNRF5Board nrf52822" as your board.
 *    Choose the correct parameters and programmer in the Tools menu.
 */

//Simple program to demonstrate that both the LED and Serial are working correctly on the breakout board:
// https://www.openhardware.io/view/471/Ebyte-nRF52832-Small-Breakout-Board
//Note: Compile and upload from Arduino IDE using "MyNRF5Board nRF52832" as the board.
//
// Many thanks to d00616 for this framework!


#define MY_CORE_ONLY

#include <nrf.h>
#include <MySensors.h>

void setup() {
  NRF_POWER->DCDCEN=1;  //enable the DCDC voltage regulator as the default.

  //guarantee RESET pin is working
  //if (((NRF_UICR-> PSELRESET[0])==0xFFFFFFFF) && ((NRF_UICR-> PSELRESET[1])==0xFFFFFFFF)) { //if the two RESET registers are erased
    //NRF_NVMC->CONFIG=1;  // Write enable the UICR
    //NRF_UICR-> PSELRESET[0]=21;  //designate pin P0.21 as the RESET pin
    //NRF_UICR-> PSELRESET[1]=21;  //designate pin P0.21 as the RESET pin
    //NRF_NVMC->CONFIG=0;  // Put the UICR back into read-only mode.
  //}
  
  Serial.begin(9600);
  Serial.println();
  Serial.println("Starting...");
  //hwPinMode(LED_BUILTIN,OUTPUT_H0H1);
  hwPinMode(RED_LED,OUTPUT_H0H1);
  hwPinMode(YELLOW_LED,OUTPUT_H0H1);
  hwPinMode(GREEN_LED,OUTPUT_H0H1);
  hwPinMode(BLUE_LED,OUTPUT_H0H1);
  digitalWrite(RED_LED,HIGH);
  digitalWrite(YELLOW_LED,HIGH);
  digitalWrite(GREEN_LED,HIGH);
  digitalWrite(BLUE_LED,HIGH);
  delay(2000); 
}


uint32_t blinkCounter=0;
void loop() {
  Serial.print(blinkCounter++);
  Serial.println(", HIGH");
  digitalWrite(GREEN_LED,HIGH);
  delay(500);
  digitalWrite(RED_LED,LOW);
  delay(500);
  Serial.print(blinkCounter++);
  Serial.println(", LOW");
  digitalWrite(GREEN_LED,LOW);
  delay(500);
  digitalWrite(RED_LED,HIGH);
  delay(500);
}
